from __future__ import absolute_import

from django.conf.urls import url, include

from .views import (Search, PageDetailView,
                    PageListView, RootPageDetailView)

urlpatterns = [
   url(regex=r'^$',
       view=RootPageDetailView.as_view(),
       name='root'),
   url(regex=r'^search/$',
       view=Search.as_view(),
       name='search'),
   url(regex=r'^site_map/$',
       view=PageListView.as_view(),
       name='site_map'),
   url(regex=r'^dmcm/edit/',
       view=include('dmcm.edit.urls', namespace='edit')),
   url(regex=r'^(?P<slug>[-\w]+).html$',
       view=PageDetailView.as_view(),
       name='page_detail_html'),
   url(regex=r'^(?P<slug>[-\w]+)/$',
       view=PageDetailView.as_view(),
       name='page_detail'),
]



from __future__ import absolute_import

from django.conf import settings
from django.core.urlresolvers import reverse
from django.views.generic import ListView
from django.views.generic.base import ContextMixin
from django.views.generic.edit import CreateView, UpdateView

from braces.views import LoginRequiredMixin

from ..models import Page
from ..edit.forms import PageForm


class LogoutUrlMixin(ContextMixin):
    def get_context_data(self, **kwargs):
        if 'logout_url' not in kwargs:
            kwargs['logout_url'] = settings.LOGOUT_URL
        return super(LogoutUrlMixin, self).get_context_data(**kwargs)


class PageListView(LoginRequiredMixin, LogoutUrlMixin, ListView):
    template_name = 'dmcm/edit/page_list.html'
    model = Page


class PageCreateView(LoginRequiredMixin, LogoutUrlMixin, CreateView):
    template_name = 'dmcm/edit/page_detail.html'
    model = Page
    form_class = PageForm

    def get_success_url(self):
        return reverse('dmcm:page_detail', args=(self.object.slug,))


class PageUpdateView(LoginRequiredMixin, LogoutUrlMixin, UpdateView):
    template_name = 'dmcm/edit/page_detail.html'
    model = Page
    form_class = PageForm

    def get_success_url(self):
        return reverse('dmcm:page_detail', args=(self.object.slug,))



from __future__ import absolute_import

from django.conf.urls import url

from .views import PageCreateView, PageListView, PageUpdateView

urlpatterns = [
    url(regex=r'^$',
       view=PageListView.as_view(),
       name='edit'),
    url(regex=r'^page/$',
       view=PageListView.as_view(),
       name='list_pages'),
    url(regex=r'^page/add/$',
       view=PageCreateView.as_view(),
       name='add_page'),
    url(regex=r'^(?P<slug>[-\w]+)/$',
       view=PageUpdateView.as_view(),
       name='update_page'),
]
